@@ -26,6 +26,6 @@ class Brain:
         return result[prediction[0][0][0]]
 
     def predict_profiler(self, image):
-        tf.profiler.experimental.start(Config.get("LOGS_FOLDER"))
+        tf.profiler.experimental.start(Config("LOGS_FOLDER"))
         self.model.predict(image)
         tf.profiler.experimental.stop()
\ No newline at end of file
