@@ -14,6 +14,10 @@ class ConfigEnum():
         "NORMALIZATION_ENABLED": True,
         "CNN_DEFAULT_MODEL": resource_filename(__name__, 'model/modelCNN-1605022224.h5')
     }
+
+    def __new__(cls, key):
+        return ConfigEnum.get(key)
+
     def get(key):
         return ConfigEnum.dict[key]
     
